==> org.polarsys.kitalpha.ad.viewpoint.dsl.generation.core.source_1.2.2.201812041251.jar: org/polarsys/kitalpha/ad/viewpoint/dsl/generation/core/util/task/GetFullProjectNameTask.java <==
/*******************************************************************************
 * Copyright (c) 2014 Thales Global Services S.A.S.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *  
 * Contributors:
 *   Thales Global Services S.A.S - initial API and implementation
 ******************************************************************************/

package org.polarsys.kitalpha.ad.viewpoint.dsl.generation.core.util.task;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.egf.core.producer.InvocationException;
import org.eclipse.egf.ftask.producer.context.ITaskProductionContext;
import org.eclipse.egf.ftask.producer.invocation.ITaskProduction;

/**
 * @author Boubekeur Zendagui
 */

public class GetFullProjectNameTask implements ITaskProduction {

	public void preExecute(ITaskProductionContext productionContext,
			IProgressMonitor monitor) throws InvocationException {
	}


	public void doExecute(ITaskProductionContext productionContext,
			IProgressMonitor monitor) throws InvocationException {
		String oldResourceName = productionContext.getInputValue("old.resource.name", String.class);
		String resourceNameAddition = productionContext.getInputValue("resource.name.addition", String.class);
		if (resourceNameAddition != null && resourceNameAddition.length() >0)
			productionContext.setOutputValue("new.resource.name", 
												oldResourceName+"."+resourceNameAddition);
		else
			productionContext.setOutputValue("new.resource.name", oldResourceName);
	}

	public void postExecute(ITaskProductionContext productionContext,
			IProgressMonitor monitor) throws InvocationException {
	}

}

==> org.polarsys.kitalpha.ad.viewpoint.dsl.generation.core.source_1.4.0.201910211249.jar: org/polarsys/kitalpha/ad/viewpoint/dsl/generation/core/util/task/GetFullProjectNameTask.java <==
/*******************************************************************************
 * Copyright (c) 2014, 2018 Thales Global Services S.A.S.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *  
 * Contributors:
 *   Thales Global Services S.A.S - initial API and implementation
 ******************************************************************************/

package org.polarsys.kitalpha.ad.viewpoint.dsl.generation.core.util.task;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.egf.core.producer.InvocationException;
import org.eclipse.egf.ftask.producer.context.ITaskProductionContext;
import org.eclipse.egf.ftask.producer.invocation.ITaskProduction;

/**
 * @author Boubekeur Zendagui
 */

public class GetFullProjectNameTask implements ITaskProduction {

	@Override
	public void preExecute(ITaskProductionContext productionContext,
			IProgressMonitor monitor) throws InvocationException {
	}


	@Override
	public void doExecute(ITaskProductionContext productionContext,
			IProgressMonitor monitor) throws InvocationException {
		String oldResourceName = productionContext.getInputValue("old.resource.name", String.class);
		String resourceNameAddition = productionContext.getInputValue("resource.name.addition", String.class);
		if (resourceNameAddition != null && resourceNameAddition.length() >0) {
			productionContext.setOutputValue("new.resource.name", 
												oldResourceName+"."+resourceNameAddition);
		} else {
			productionContext.setOutputValue("new.resource.name", oldResourceName);
		}
	}

	@Override
	public void postExecute(ITaskProductionContext productionContext,
			IProgressMonitor monitor) throws InvocationException {
	}

}
